<?php
/*
 * If the current post is protected by a password and the visitor has not yet
 * entered the password we will return early without loading the comments.
 */
if ( post_password_required() ) return;

//Translation Theme Options
$spyropress_translate['translate-title'] = get_setting( 'translate' ) ?  get_setting( 'translate-title', 'Post has' ) : esc_html__( 'Post has', 'heartify' );
$spyropress_translate['comment'] = get_setting( 'translate' ) ?  get_setting( 'translate-comment', 'Comment' ) : esc_html__( 'Comment', 'heartify' );
$spyropress_translate['comments'] = get_setting( 'translate' ) ?  get_setting( 'translate-comments', 'Comments' ) : esc_html__( 'Comments', 'heartify' );
$spyropress_translate['comments-off'] = get_setting( 'translate' ) ?  get_setting( 'translate-comments-off', 'Comments are closed.' ) : esc_html__( 'Comments are closed.', 'heartify' );

?>

<div class="comments">
<?php if ( ! comments_open() ) { echo '<p class="no-comments">' . esc_html( $spyropress_translate['comments-off'] ) . '</p>'; } ?>
	<?php if ( have_comments() ) { ?>
        <h4>
		 <?php
            $spyropress_num_comments = get_comments_number();
            if( $spyropress_num_comments != 1 )
                printf( '%1$s %3$s %2$s', esc_html( $spyropress_translate['translate-title'] ), esc_html( $spyropress_translate['comments'] ), number_format_i18n( $spyropress_num_comments ) );
            else
                printf( '%1$s %3$s %2$s', esc_html( $spyropress_translate['translate-title'] ), esc_html( $spyropress_translate['comment'] ), number_format_i18n( $spyropress_num_comments ) );
        ?>
		</h4>

		<ul class="clearfix post-comment">
			<?php
				wp_list_comments( array(
					'format'      => 'html5',
					'short_ping'  => true,
                    'callback' => 'spyropress_comment'
				) );
			?>
		</ul><!-- .comment-list -->

		<?php
			// Are there comments to navigate through?
			if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
		?>
		<nav class="navigation comment-navigation" role="navigation">
			<h1 class="screen-reader-text section-heading"><?php echo esc_html__( 'Comment navigation', 'heartify' ); ?></h1>
			<div class="nav-previous"><?php previous_comments_link( esc_html__( '&larr; Older Comments', 'heartify' ) ); ?></div>
			<div class="nav-next"><?php next_comments_link( esc_html__( 'Newer Comments &rarr;', 'heartify' ) ); ?></div>
		</nav><!-- .comment-navigation -->
		<?php endif; // Check for comment navigation ?>

	<?php
        }
    ?>
</div><!-- #comments -->
<div class="comment-form">
    <?php
        $req = get_option( 'require_name_email' );
        $aria_req = ( $req ? " aria-required='true'" : '' );
    
        $spyropress_fields = array();
        $spyropress_fields['author'] = '<div class="row"><div id="label-author" for="author" class="col-md-4"><input id="author" name="author" type="text"  placeholder="Name" value="' . esc_attr( $commenter['comment_author'] ) . '"' . $aria_req . ' /></div>';
        $spyropress_fields['email'] = '<div id="label-email" for="email" class="col-md-4"><input id="email" name="email" type="text"  placeholder="Email" value="' . esc_attr(  $commenter['comment_author_email'] ) . '"' . $aria_req . ' /></div>';
        $spyropress_fields['url'] = '<div id="label-url" for="url" class="col-md-4"><input id="url" name="url" type="text"  placeholder="Website" value="' . esc_attr( $commenter['comment_author_url'] ) . '" /></div></div>';
    
        $spyropress_args = array(
            'fields' => $spyropress_fields,
            'comment_field' => '<div class="row"><div class="col-md-12"><textarea id="comment" name="comment"  placeholder="Message"></textarea></div></div>',
            'format' => 'html5',
            'id_form' => 'comment-form',
            'label_submit' => esc_html__( 'Submit Comment', 'heartify' ),
            'comment_notes_before' => '',
            'comment_notes_after' => '<p>' . esc_html__( 'Your email address will not be published. Required fields are marked *', 'heartify' ) . '</p>'
        );
    
        ob_start();
        comment_form( $spyropress_args );
        $spyropress_comment_form = ob_get_clean();
    
        $spyropress_comment_form = str_replace( '<p class="form-submit">', '<p class="form-submit field">', $spyropress_comment_form );
    
        echo $spyropress_comment_form;
    ?>
</div>