<?php
/**
 * Module: Gmap
 * Add google map into the page layout wherever needed.
 *
 * @author 		SpyroSol
 * @category 	BuilderModules
 * @package 	Spyropress
 */

class Spyropress_Module_Gmap extends SpyropressBuilderModule {

    public function __construct() {

        // Widget variable settings
        $this->description = esc_html__( 'Add google map markers work with google map row only.', 'heartify' );
        $this->id_base = 'gmap_markers';
        $this->name = esc_html__( 'Google Map Markers', 'heartify' );

        // Fields
        $this->fields = array(
        
            array(
                'label' => esc_html__( 'Latitude', 'heartify' ),
                'id' => 'lat',
                'type' => 'text'
            ),
            
            array(
                'label' => esc_html__( 'Longitude', 'heartify' ),
                'id' => 'long',
                'type' => 'text'
            )
               
        );

        $this->create_widget();
    }

    function widget( $spyropress_args, $spyropress_instance ) {
         // extracting info
        $spyropress_instance = wp_parse_args( $spyropress_instance, array(
            'lat' => 40.6700,
            'long' => -73.9400
            
        ) );
        
        extract( $spyropress_args ); extract( $spyropress_instance );
        
        wp_enqueue_script( 'gmap-api', 'https://maps.googleapis.com/maps/api/js?key=AIzaSyDW40y4kdsjsz714OVTvrw7woVCpD8EbLE', false, false, true );
        
        echo '<div id="map" ></div>';
        $markers_js = '';
        $markers_js .= "
        google.maps.event.addDomListener(window, 'load', init);
            function init() {
                // Basic options for a simple Google Map
                // For more options see: https://developers.google.com/maps/documentation/javascript/reference#MapOptions
                var mapOptions = {
                    // How zoomed in you want the map to start at (always required)
                    zoom: 11,

                    // The latitude and longitude to center the map (always required)
                    center: new google.maps.LatLng($lat, $long), // New York

                    // How you would like to style the map. 
                    // This is where you would paste any style found on Snazzy Maps.
                    styles: [
				{
					featureType:'water',
					elementType:'all',
					stylers:[{hue:'#e9ebed'},{saturation:-78},{lightness:67},{visibility:'simplified'}					]				},{					featureType:'landscape',					elementType:'all',					stylers:[						{hue:'#ffffff'},						{saturation:-100},						{lightness:100},						{visibility:'simplified'}					]				},{					featureType:'road',					elementType:'geometry',					stylers:[						{hue:'#bbc0c4'},						{saturation:-93},						{lightness:31},						{visibility:'simplified'}					]				},{					featureType:'poi',					elementType:'all',					stylers:[						{hue:'#ffffff'},						{saturation:-100},						{lightness:100},						{visibility:'off'}					]				},{					featureType:'road.local',					elementType:'geometry',					stylers:[						{hue:'#e9ebed'},						{saturation:-90},						{lightness:-8},						{visibility:'simplified'}					]				},{					featureType:'transit',					elementType:'all',					stylers:[						{hue:'#e9ebed'},						{saturation:10},						{lightness:69},						{visibility:'on'}					]				},{					featureType:'administrative.locality',					elementType:'all',					stylers:[						{hue:'#2c2e33'},						{saturation:7},						{lightness:19},						{visibility:'on'}					]				},{					featureType:'road',					elementType:'labels',					stylers:[						{hue:'#bbc0c4'},						{saturation:-93},						{lightness:31},						{visibility:'on'}					]				},{					featureType:'road.arterial',					elementType:'labels',					stylers:[						{hue:'#bbc0c4'},						{saturation:-93},						{lightness:-2},						{visibility:'simplified'}					]				}			]
                };

                // Get the HTML DOM element that will contain your map 
                // We are using a div with id='map' seen below in the <body>
                var mapElement = document.getElementById('map');

                // Create the Google Map using out element and options defined above
                var map = new google.maps.Map(mapElement, mapOptions);
        }";
        
        add_inline_js( $markers_js );
    }
}
//Class Spyropress_Module_Gmap
spyropress_builder_register_module( 'Spyropress_Module_Gmap' );