<?php
/**
 * Module: Heading
 * Add headings into the page layout wherever needed.
 *
 * @author 		SpyroSol
 * @category 	BuilderModules
 * @package 	Spyropress
 */

class Spyropress_Module_Heading extends SpyropressBuilderModule {

    public function __construct() {

        // Widget variable settings
        $this->path =  get_template_directory().'/framework/builder/modules/heading';
        $this->cssclass = 'module-heading';
        $this->description = esc_html__( 'Add headings into the page layout wherever needed.', 'heartify' );
        $this->id_base = 'spyropress_heading';
        $this->name = esc_html__( 'Heading', 'heartify' );

        //template.
        $this->templates['view'] = array( 'view' => 'view.php', 'label' =>esc_html__( 'Center Content', 'heartify' ) );
        $this->templates['view-one'] = array( 'view' => 'view-one.php', 'label' =>esc_html__( 'Center Small Content', 'heartify' ) );
        $this->templates['view-two'] = array( 'view' => 'view-two.php', 'label' =>esc_html__( 'Contact Section', 'heartify' ) );
        $this->templates['view-three'] = array( 'view' => 'view-three.php', 'label' =>esc_html__( 'Left Content', 'heartify' ) );
        
        // Fields
        $this->fields = array(
            
            array(
                'label' => esc_html__( 'Template', 'heartify' ),
                'id' => 'template',
                'class' => 'enable_changer section-full',
                'type' => 'select',
                'options' => $this->get_option_templates()
            ),
            
            array( 'type' => 'row' ),

                array( 'type' => 'col', 'size' => 6 ),
                
                    array(
                        'label' => esc_html__( 'Heading Text', 'heartify' ),
                        'id' => 'heading',
                        'type' => 'text',
                    ),
                    
                    array(
                        'label' => esc_html__( 'HTML Tag', 'heartify' ),
                        'id' => 'html_tag',
                        'type' => 'select',
                        'options' => array(
                            'h1' => esc_html__( 'H1', 'heartify' ),
                            'h2' => esc_html__( 'H2', 'heartify' ),
                            'h3' => esc_html__( 'H3', 'heartify' ),
                            'h4' => esc_html__( 'H4', 'heartify' ),
                            'h5' => esc_html__( 'H5', 'heartify' ),
                            'h6' => esc_html__( 'H6', 'heartify' )
                        ),
                        'std' => 'h1'
                    ),
                
                array( 'type' => 'col_end' ),

                array( 'type' => 'col', 'size' => 6 ),
                
                    array(
                        'label' => esc_html__( 'Sub Heading Text', 'heartify' ),
                        'id' => 'sub_heading',
                        'type' => 'text',
                    ),
                    
                    array(
                        'label' => esc_html__( 'HTML Tag', 'heartify' ),
                        'id' => 'html_sub_tag',
                        'type' => 'select',
                        'options' => array(
                            'h1' => esc_html__( 'H1', 'heartify' ),
                            'h2' => esc_html__( 'H2', 'heartify' ),
                            'h3' => esc_html__( 'H3', 'heartify' ),
                            'h4' => esc_html__( 'H4', 'heartify' ),
                            'h5' => esc_html__( 'H5', 'heartify' ),
                            'h6' => esc_html__( 'H6', 'heartify' )
                        ),
                        'std' => 'h1'
                    ),
                
                array( 'type' => 'col_end' ),

            array( 'type' => 'row_end' ),  
            
            array(
                'label' => esc_html__( 'Content', 'heartify' ),
                'id' => 'content',
                'type' => 'textarea',
                'rows' => 5
            ),
            array(
                'label' => esc_html__( 'Setting', 'heartify' ),
                'class' => 'template view-two view section-full',
                'type' => 'toggle',
            ), 
                 array( 'type' => 'row' ),
                    
                    array( 'type' => 'col', 'size' => 6 ),
                        array(
                            'id' => 'postion',
                            'type' => 'select',
                            'class' => 'template view-two section-full',
                            'desc' => esc_html__( 'Text Postion.', 'heartify' ),
                            'options' => array(
                                'text-left' => esc_html__( 'Left','heartify' ),
                                'text-center' => esc_html__( 'Center','heartify' ),
                                'text-right' => esc_html__( 'Right','heartify' )
                            )
                        ),
                    
                    array( 'type' => 'col_end' ),
                    
                    array( 'type' => 'col', 'size' => 6 ),
                    
                            array(
                        		'label' => esc_html__( 'Offset', 'heartify' ),
                        		'id' => 'offset',
                                'class' => 'template view-two section-full',
                                'type' => 'checkbox',
                                'options' => array(
                                    '1' => esc_html__( 'Disable Offset Class.', 'heartify' ),
                                )
                        	),
                        
                        array( 'type' => 'col_end' ),
                     array( 'type' => 'row_end' ),
                     
                     array(
                		'label' => esc_html__( 'Font Color', 'heartify' ),
                		'id' => 'color_cls',
                        'class' => 'template view section-full',
                        'desc' => esc_html__( 'Select font color of content.', 'heartify' ),
                        'type' => 'select',
                        'options' => array(
                            'heading-white' => esc_html__( 'White','heartify' ),
                            'heading-center-half' => esc_html__( 'Block','heartify' ),
                        )
                	), 
            
            array(
        		'type' => 'toggle_end'
        	)  
            
        );

        $this->create_widget();
    }

    function widget( $spyropress_args, $spyropress_instance ) {

        // extracting info
        extract($spyropress_args);extract($spyropress_instance);
        
        //Template of Module.
        $spyropress_template = isset( $spyropress_instance['template'] ) ? $spyropress_instance['template'] : '';

        // get view to render
        require( $this->get_view( $spyropress_template ) );
    }
}
//class Spyropress_Module_Heading
spyropress_builder_register_module( 'Spyropress_Module_Heading' );