<?php
/**
 * Module: Icon Teaser
 * Display a brief text with a link and use hundreds of built-in icons
 *
 * @author 		SpyroSol
 * @category 	BuilderModules
 * @package 	Spyropress
 */

class Spyropress_Module_Icon_Teaser extends SpyropressBuilderModule {

    /**
     * Constructor
     */
    public function __construct() {

        // Widget variable settings
        $this->path = $this->path = get_template_directory().'/framework/builder/modules/icon-teaser';
        $this->cssclass = 'module-icon-teaser';
        $this->description = esc_html__( 'Display a brief text with a link and use of icons.', 'heartify' );
        $this->id_base = 'spyropress_icon_teaser';
        $this->name = esc_html__( 'Icon Teaser', 'heartify' );
        
         //template.
        $this->templates['view'] = array( 'view' => 'view.php', 'label' =>esc_html__( 'Style One', 'heartify' ) );
        $this->templates['view-one'] = array( 'view' => 'view-one.php', 'label' =>esc_html__( 'Box Icon', 'heartify' ) );
        $this->templates['view-two'] = array( 'view' => 'view-two.php', 'label' =>esc_html__( 'Style Three', 'heartify' ) );
        $this->templates['view-three'] = array( 'view' => 'view-three.php', 'label' =>esc_html__( 'Style Four', 'heartify' ) ); 
        $this->templates['view-four'] = array( 'view' => 'view-four.php', 'label' =>esc_html__( 'Style Five', 'heartify' ) ); 
        
        
        // Fields
        $this->fields = array (
            
            array(
                'label' => esc_html__( 'Template', 'heartify' ),
                'id' => 'template',
                'class' => 'enable_changer section-full',
                'type' => 'select',
                'options' => $this->get_option_templates()
            ),
            
            array(
                'label' => esc_html__( 'Number of Columns', 'heartify' ),
                'id' => 'columns',
                'type' => 'range_slider',
                'std' => 3,
                'max' => 4
            ),
            
            array(
                'label' => esc_html__( 'Icon Teaser', 'heartify' ),
                'id' => 'teasers',
                'type' => 'repeater',
                'item_title' => 'title',
                'fields' => array(
            
                    array(
                        'label' => esc_html__( 'Title', 'heartify' ),
                        'id' => 'title',
                        'type' => 'text'
                    ),
                    
                    array(
                        'label' => esc_html__( 'Icon', 'heartify' ),
                        'id' => 'icon',
                        'type' => 'upload'
                    ), 
        
                    array(
                        'label' => esc_html__( 'Content', 'heartify' ),
                        'id' => 'content',
                        'type' => 'textarea',
                        'rows' => 6
                    ),
                    
                    array(
                        'label' => esc_html__( 'Box Color', 'heartify' ),
                        'id' => 'color',
                        'class' => 'template view-one section-full',
                        'type' => 'colorpicker'
                    ),
                )
            ) 
        );
        
        $this->create_widget();
    }

    function widget( $spyropress_args, $spyropress_instance ) {
        
        // extracting info
        extract($spyropress_args);extract($spyropress_instance);
        
        //Module Template.
        $spyropress_template = isset( $spyropress_instance['template'] ) ? $spyropress_instance['template'] : '';

        // get view to render
        require( $this->get_view( $template ) );
        
    }
    
    function spyropress_icon_teaser_generator( $spyropress_item, $spyropress_atts ) {
       
       //content return.
       return
       '<div class="' . esc_attr( $spyropress_atts['column_class'] ) . '">
			<img class="pull-center icon" src="'. esc_url( $spyropress_item['icon'] ) .'" alt="icon" />
			<div class="info-col">
				<h5>'. esc_html( $spyropress_item['title'] ) .'</h5>
				<p>'. esc_html( $spyropress_item['content'] ) .'</p>
			</div>
		</div>'; 
    }
    
    function spyropress_icon_teaser_generator_two( $spyropress_item, $spyropress_atts ) {
       
       //box custom css color 
       $spyropress_custom_css = isset( $spyropress_item['color'] )? 'style="background:'. esc_attr( $spyropress_item['color'] ) .';"' : '';
       
       //content return.
       return
       '<div class="' . esc_attr( $spyropress_atts['column_class'] ) . '" '. esc_attr( $spyropress_custom_css ) .'>
            <div class="clearfix"></div>
            <img class="pull-center icon" src="'. esc_url( $spyropress_item['icon'] ) .'" alt="icon" />
			<div class="info-col">
				<h5>'. esc_html( $spyropress_item['title'] ) .'</h5>
				<p>'. esc_html( $spyropress_item['content'] ) .'</p>
			</div>
		</div>'; 
    }
    
    function spyropress_icon_teaser_generator_three( $spyropress_item, $spyropress_atts ) {
       
       //content return.
       return
       '<div class="' . esc_attr( $spyropress_atts['column_class'] ) . '">
            <img class="pull-left icon" src="'. esc_url( $spyropress_item['icon'] ) .'" alt="icon" />
			<div class="info-col">
				<h5>'. esc_html( $spyropress_item['title'] ) .'</h5>
				<p>'. esc_html( $spyropress_item['content'] ) .'</p>
			</div><div class="bottom-space-50"></div>
		</div>'; 
    }
    
    function spyropress_icon_teaser_generator_four( $spyropress_item, $spyropress_atts ) {
       
       $spyropress_icon_class = ( 'col-md-6 column_first' == $spyropress_atts['column_class'] )? 'pull-right icon' : 'pull-left icon';
       //content return.
       return
       '<div class="' . esc_attr( $spyropress_atts['column_class'] ) . '">
			<img class="'. esc_attr( $spyropress_icon_class ) .'" src="'. esc_url( $spyropress_item['icon'] ) .'" alt="icon" />
			<div class="info-col">
				<h5>'. esc_html( $spyropress_item['title'] ) .'</h5>
				<p>'. esc_html( $spyropress_item['content'] ) .'</p>
			</div>
            <div class="bottom-space-50"></div>
            <div class="clearfix"></div>
		</div>'; 
    }
    
    function spyropress_icon_teaser_generator_five( $spyropress_item, $spyropress_atts ) {
  
       //content return.
       return
       '<div class="' . esc_attr( $spyropress_atts['column_class'] ) . ' text-center">
			<img class="pull-center icon" src="'. esc_url( $spyropress_item['icon'] ) .'" alt="icon" />
			<div class="info-col">
				<h5>'. esc_html( $spyropress_item['title'] ) .'</h5>
				<p>'. esc_html( $spyropress_item['content'] ) .'</p>
			</div>
		</div>'; 
    }

}
// class Spyropress_Module_Icon_Teaser
spyropress_builder_register_module( 'Spyropress_Module_Icon_Teaser' );