<?php
/**
 * Module: Posts
 * Display a list of recent posts
 *
 * @author 		SpyroSol
 * @category 	BuilderModules
 * @package 	Spyropress
 */

class Spyropress_Module_Recent_Posts extends SpyropressBuilderModule{

    public function __construct(){
        
        // Widget variable settings.
        $this->path = $this->path = get_template_directory().'/framework/builder/modules/recent-posts';
        $this->description = esc_html__( 'Display a list of recent posts.', 'heartify' );
        $this->id_base = 'srecent_posts';
        $this->cssclass = 'recent-posts';
        $this->name = esc_html__( 'Recent Posts', 'heartify' );

        // Fields
        $this->fields = array(

            array(
                'label' => esc_html__( 'Number of items per page', 'heartify' ),
                'id' => 'limit',
                'type' => 'range_slider',
                'std' => 6
            ),

            array(
                'label' => esc_html__( 'Number of columns', 'heartify' ),
                'id' => 'columns',
                'type' => 'range_slider',
                'std' => 4,
                'max' => 4
            ),

            array(
                'label' => esc_html__( 'Category', 'heartify' ),
                'id' => 'cat',
                'type' => 'multi_select',
                'options' => spyropress_get_taxonomies( 'category' )
            ),

            array(
                'id' => 'url_enable',
                'type' => 'checkbox',
                'options' => array(
                    '1' => esc_html__( 'Show Archive Link','heartify' )
                )
            ),

            array(
                'label' => esc_html__( 'Link to Text', 'heartify' ),
                'id' => 'url_text',
                'type' => 'text',
                'std' => 'View All'
            )
        );

        $this->create_widget();
    }

    function widget( $spyropress_args, $spyropress_instance ){

        // extracting info
        extract( $spyropress_args );extract( $spyropress_instance );

        // get view to render
        require( $this->get_view() );
    }

    function spyropress_query( $spyropress_atts, $spyropress_content = null ){

        $spyropress_default = array(
            'post_type' => 'post',
            'limit' => -1,
            'columns' => 2,
            'column_class'=> 'works-item',
            'pagination' => false,
            'callback' => array( $this, 'spyropress_generate_item' ) );
        $spyropress_atts = wp_parse_args( $spyropress_atts, $spyropress_default );

        if ( !empty( $spyropress_atts['cat'] ) ){

            $spyropress_atts['tax_query']['relation'] = 'OR';
            if ( !empty( $atts['cat'] ) ){
                $atts['tax_query'][] = array(
                    'taxonomy' => 'category',
                    'field' => 'slug',
                    'terms' => $spyropress_atts['cat'],
                );
                unset( $spyropress_atts['cat'] );
            }
        }

        if ( $spyropress_content )
            return token_repalce( $spyropress_content, spyropress_query_generator( $spyropress_atts ) );

        return spyropress_query_generator( $spyropress_atts );
    }

    // Item HTML Generator
    function spyropress_generate_item( $post_ID, $atts ){

        // these arguments will be available from inside $content
        $spyropress_image = array(
            'post_id' => $post_ID,
            'type' => 'src',
            'echo' => false,
        );
        $spyropress_image_url = get_image( $spyropress_image );
        $spyropress_image_tag = '';
        if( $spyropress_image_url )
            $spyropress_image_tag = 
            '<div class="post-img">
                <img src="'. esc_url( $spyropress_image_url ) .'" class="img-responsive" alt="" />
                <img class="ab-icon" src="'. esc_url( assets_img( 'post-icon.png' ) ) .'" alt="" />
            </div>';
         

        // item tempalte
        $spyropress_item_tmpl = '
        <div class="' . esc_attr( $atts['column_class'] ) . '">
			<div class="blog-post">
				'. $spyropress_image_tag .'
				<div class="info-col">
					<a href="' . esc_url( get_permalink() ) . '">
						<h5>' . get_the_title() . '</h5>
					</a>
					'. spyropress_get_excerpt( array( 'length' => 15, 'link_to_post' => '' ) ) .'
				</div>
				<ul class="list-inline list-unstyled post-nav">
					<li class="post-links">'. sprintf( '<a href="%1$s"><i class="icon-user"></i> %2$s</a>', esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) ,esc_html( get_the_author() ) ) .'</li>
					<li class="post-links"><a href="' . esc_url( get_permalink() ) . '"><i class="icon-calendar"></i> '. get_the_date( 'd M Y' ) .'</a></li>
				</ul>
			</div><div class="bottom-space-50"></div>
            <div class="clearfix"></div>
		</div>';

        return $spyropress_item_tmpl;
    }
}
//register class Spyropress_Module_Recent_Posts
spyropress_builder_register_module('Spyropress_Module_Recent_Posts');