<?php

/**
 * Option/Settings Helper Functions
 *
 * @category Utilities
 * @package Spyropress
 *
 */

/** Option Getter and Formatter **********************/

function get_float_class( $float ) {
    
    // check for null
    if ( ! $float ) return;

    $allowed_floats = array( 'left' => 'pull-left', 'right' => 'pull-right' );

    if ( in_array( $float, array_keys( $allowed_floats ) ) )
        $float = $allowed_floats[$float];

    return $float;
}

/**
 * Row Class
 */
function get_row_class( $return = false ) {
    global $spyropress;

    if ( $return )
        return $spyropress->row_class;
    echo $spyropress->row_class;
}

/**
 * Column Class
 */
function get_column_class( $column ) {
    if( 'skt' == get_html_framework() ) return get_skeleton_col_class( $column );
    
    if( 'bs' == get_html_framework() ) return get_bootstrap_class( $column );
    
    if( 'bs3' == get_html_framework() ) return get_bootstrap3_class( $column );
    
    if( 'fd3' == get_html_framework() ) return get_foundation3_col_class( $column );
}

/**
 * Bootstrap Class
 */
function get_bootstrap_class( $column ) {

    $class = 'span12';

    switch ( $column ) {
        case 2:
            $class = 'span6';
            break;
        case 3:
            $class = 'span4';
            break;
        case 4:
            $class = 'span3';
            break;
        case 6:
            $class = 'span2';
            break;
    }

    return $class;
}

/**
 * Bootstrap Class
 */
function get_bootstrap3_class( $column ) {

    $class = 'col-md-12';

    switch ( $column ) {
        case 2:
            $class = 'col-md-6';
            break;
        case 3:
            $class = 'col-md-4';
            break;
        case 4:
            $class = 'col-md-3';
            break;
        case 6:
            $class = 'col-md-2';
            break;
    }

    return $class;
}

/**
 * Skeleton Classes
 */
function get_skeleton_col_class( $column ) {

    $class = get_skeleton_class( 16 );

    switch ( $column ) {
        case 2:
            $class = get_skeleton_class( 8 );
            break;
        case 3:
            $class = get_skeleton_class( '1/3' );
            break;
        case 4:
            $class = get_skeleton_class( 4 );
            break;
        case 8:
            $class = get_skeleton_class( 2 );
            break;
    }

    return $class;
}

function get_skeleton_class( $column ) {
    
    $classes = array(
        1 => 'one columns',
        2 => 'two columns',
        3 => 'three columns',
        4 => 'four columns',
        5 => 'five columns',
        6 => 'six columns',
        7 => 'seven columns',
        8 => 'eight columns',
        9 => 'nine columns',
        10 => 'ten columns',
        11 => 'eleven columns',
        12 => 'twelve columns',
        13 => 'thirteen columns',
        14 => 'fourteen columns',
        15 => 'fifteen columns',
        16 => 'sixteen columns',
        '1/3' => 'one-third column',
        '2/3' => 'two-thirds column',
    );
    
    return $classes[$column];
}

function get_admin_column_class( $column ) {
    
    $class = '';
    if( 12 == get_grid_columns() ) {

        $class = 'span12';
        
        switch ( $column ) {
            case 2:
                $class = 'span6';
                break;
            case 3:
                $class = 'span4';
                break;
            case 4:
                $class = 'span3';
                break;
            case 6:
                $class = 'span2';
                break;
        }
    }
    elseif( 16 == get_grid_columns() ) {

        $class = 'span16';
        
        switch ( $column ) {
            case 2:
                $class = 'span8';
                break;
            case 3:
                $class = 'span1by3';
                break;
            case 4:
                $class = 'span4';
                break;
            case 8:
                $class = 'span2';
                break;
        }
    }
    
    return $class;
}

/**
 * Foundation3 Classes
 */

function get_foundation3_col_class( $column ) {

    $class = get_foundation3_class( 12 );

    switch ( $column ) {
        case 2:
            $class = get_foundation3_class( 6 );
            break;
        case 3:
            $class = get_foundation3_class( 4 );
            break;
        case 4:
            $class = get_foundation3_class( 3 );
            break;
        case 6:
            $class = get_foundation3_class( 2 );
            break;
    }

    return $class;
}

function get_foundation3_class( $column ) {

    $classes = array(
        1 => 'one columns',
        2 => 'two columns',
        3 => 'three columns',
        4 => 'four columns',
        5 => 'five columns',
        6 => 'six columns',
        7 => 'seven columns',
        8 => 'eight columns',
        9 => 'nine columns',
        10 => 'ten columns',
        11 => 'eleven columns',
        12 => 'twelve columns'
    );
    
    return $classes[$column];
}

/**
 * Get HTML Framework
 */
function get_html_framework() {
    global $spyropress;
    return $spyropress->framework;
}

/**
 * Get Grid Column
 */
function get_grid_columns() {
    global $spyropress;
    return $spyropress->grid_columns;
}

/**
 * First Column Class accoring to framework
 */
function get_first_column_class() {
    
    // Skeleton
    if( 'skt' == get_html_framework() ) return 'alpha';
    
    // Others
    return 'column_first';
}

/**
 * Last Column Class accoring to framework
 */
function get_last_column_class() {
    
    // Skeleton
    if( 'skt' == get_html_framework() ) return 'omega';
    
    // Foundation
    if( 'fd3' == get_html_framework() ) return 'end';
    
    // Others
    return 'column_last';
}

/** Data Sources for Post Type and Taxonomies **********************/

/**
 * Buckets
 */
function spyropress_get_buckets() {
    
    $buckets = array();
    
    if ( ! post_type_exists( 'bucket' ) ) return $buckets;
    
    // get posts
    $args = array(
        'post_type' => 'bucket',
        'posts_per_page' => -1,
        'orderby' => 'title',
        'order' => 'asc'
    );
    $posts = get_posts( $args );
    if ( !empty( $posts ) ) {
        foreach ( $posts as $post ) {
            $buckets[$post->ID] = $post->post_title;
        }
    }

    return $buckets;
}

/**
 * Custom Taxonomies
 */
function spyropress_get_taxonomies( $tax = '' ) {
    
    if ( ! $tax ) return array();

    $terms = get_terms( $tax );
    $taxs = array();
    if ( !empty( $terms ) )
        foreach ( $terms as $term )
            $taxs[$term->slug] = $term->name;

    return $taxs;
}

/** Custom Data Sources ********************************************/

/**
 * jQuery Easing Options
 */
function spyropress_get_options_easing() {
    return array(
        'linear' => esc_html__( 'linear', 'heartify' ),
        'jswing' => esc_html__( 'jswing', 'heartify' ),
        'def' => esc_html__( 'def', 'heartify' ),
        'easeInQuad' => esc_html__( 'easeInQuad', 'heartify' ),
        'easeOutQuad' => esc_html__( 'easeOutQuad', 'heartify' ),
        'easeInOutQuad' => esc_html__( 'easeInOutQuad', 'heartify' ),
        'easeInCubic' => esc_html__( 'easeInCubic', 'heartify' ),
        'easeOutCubic' => esc_html__( 'easeOutCubic', 'heartify' ),
        'easeInOutCubic' => esc_html__( 'easeInOutCubic', 'heartify' ),
        'easeInQuart' => esc_html__( 'easeInQuart', 'heartify' ),
        'easeOutQuart' => esc_html__( 'easeOutQuart', 'heartify' ),
        'easeInOutQuart' => esc_html__( 'easeInOutQuart', 'heartify' ),
        'easeInQuint' => esc_html__( 'easeInQuint', 'heartify' ),
        'easeOutQuint' => esc_html__( 'easeOutQuint', 'heartify' ),
        'easeInOutQuint' => esc_html__( 'easeInOutQuint', 'heartify' ),
        'easeInSine' => esc_html__( 'easeInSine', 'heartify' ),
        'easeOutSine' => esc_html__( 'easeOutSine', 'heartify' ),
        'easeInOutSine' => esc_html__( 'easeInOutSine', 'heartify' ),
        'easeInExpo' => esc_html__( 'easeInExpo', 'heartify' ),
        'easeOutExpo' => esc_html__( 'easeOutExpo', 'heartify' ),
        'easeInOutExpo' => esc_html__( 'easeInOutExpo', 'heartify' ),
        'easeInCirc' => esc_html__( 'easeInCirc', 'heartify' ),
        'easeOutCirc' => esc_html__( 'easeOutCirc', 'heartify' ),
        'easeInOutCirc' => esc_html__( 'easeInOutCirc', 'heartify' ),
        'easeInElastic' => esc_html__( 'easeInElastic', 'heartify' ),
        'easeOutElastic' => esc_html__( 'easeOutElastic', 'heartify' ),
        'easeInOutElastic' => esc_html__( 'easeInOutElastic', 'heartify' ),
        'easeInBack' => esc_html__( 'easeInBack', 'heartify' ),
        'easeOutBack' => esc_html__( 'easeOutBack', 'heartify' ),
        'easeInOutBack' => esc_html__( 'easeInOutBack', 'heartify' ),
        'easeInBounce' => esc_html__( 'easeInBounce', 'heartify' ),
        'easeOutBounce' => esc_html__( 'easeOutBounce', 'heartify' ),
        'easeInOutBounce' => esc_html__( 'easeInOutBounce', 'heartify' ),
    );
}

function spyropress_get_options_float() {
    return array(
        'none' => esc_html__( 'None', 'heartify' ),
        'left' => esc_html__( 'Left', 'heartify' ),
        'right' => esc_html__( 'Right', 'heartify' ),
    );
}

function spyropress_get_options_link( $fields ) {
    // check for emptiness
    if ( empty( $fields ) ) $fields = array();

    return array_merge( $fields, array(
        array(
            'label' => esc_html__( 'URL/Link Setting', 'heartify' ),
            'type' => 'toggle'
        ),

        array(
            'label' => esc_html__( 'Link Text', 'heartify' ),
            'id' => 'url_text',
            'type' => 'text'
        ),

        array(
            'label' => esc_html__( 'URL/Hash', 'heartify' ),
            'id' => 'url',
            'type' => 'text'
        ),

        array(
            'label' => esc_html__( 'Link to Post/Page', 'heartify' ),
            'id' => 'link_url',
            'type' => 'custom_post',
            'post_type' => array( 'post', 'page' )
        ),

        array( 'type' => 'toggle_end' )
    ) );
}

function spyropress_get_options_fontawesome_icons(){
    
     return array(
        'fa-glass' => esc_html__( 'Glass', 'heartify' ),
        'fa-music' => esc_html__( 'Music', 'heartify' ),
        'fa-search' => esc_html__( 'Search', 'heartify' ),
        'fa-envelope-o' => esc_html__( 'Envelope Outline', 'heartify' ),
        'fa-heart' => esc_html__( 'Heart', 'heartify' ),
        'fa-star' => esc_html__( 'Star', 'heartify' ),
        'fa-star-o' => esc_html__( 'Star Outline', 'heartify' ),
        'fa-user' => esc_html__( 'User', 'heartify' ),
        'fa-film' => esc_html__( 'Film', 'heartify' ),
        'fa-th-large' => esc_html__( 'Th Large', 'heartify' ),
        'fa-th' => esc_html__( 'Th', 'heartify' ),
        'fa-th-list' => esc_html__( 'Th List', 'heartify' ),
        'fa-check' => esc_html__( 'Check', 'heartify' ),
        'fa-times' => esc_html__( 'Times', 'heartify' ),
        'fa-search-plus' => esc_html__( 'Search Plus', 'heartify' ),
        'fa-search-minus' => esc_html__( 'Search Minus', 'heartify' ),
        'fa-power-off' => esc_html__( 'Power Off', 'heartify' ),
        'fa-signal' => esc_html__( 'Signal', 'heartify' ),
        'fa-gear' => esc_html__( 'Gear', 'heartify' ),
        'fa-cog' => esc_html__( 'Cog', 'heartify' ),
        'fa-trash-o' => esc_html__( 'Trash Outline', 'heartify' ),
        'fa-home' => esc_html__( 'Home', 'heartify' ),
        'fa-file-o' => esc_html__( 'File Outline', 'heartify' ),
        'fa-clock-o' => esc_html__( 'Clock Outline', 'heartify' ),
        'fa-road' => esc_html__( 'Road', 'heartify' ),
        'fa-download' => esc_html__( 'Download', 'heartify' ),
        'fa-arrow-circle-o-down' => esc_html__( 'Arrow Circle Outline Down', 'heartify' ),
        'fa-arrow-circle-o-up' => esc_html__( 'Arrow Circle Outline Up', 'heartify' ),
        'fa-inbox' => esc_html__( 'Inbox', 'heartify' ),
        'fa-play-circle-o' => esc_html__( 'Play Circle Outline', 'heartify' ),
        'fa-rotate-right' => esc_html__( 'Rotate Right', 'heartify' ),
        'fa-repeat' => esc_html__( 'Repeat', 'heartify' ),
        'fa-refresh' => esc_html__( 'Refresh', 'heartify' ),
        'fa-list-alt' => esc_html__( 'List Alt', 'heartify' ),
        'fa-lock' => esc_html__( 'Lock', 'heartify' ),
        'fa-flag' => esc_html__( 'Flag', 'heartify' ),
        'fa-headphones' => esc_html__( 'Headphones', 'heartify' ),
        'fa-volume-off' => esc_html__( 'Volume Off', 'heartify' ),
        'fa-volume-down' => esc_html__( 'Volume Down', 'heartify' ),
        'fa-volume-up' => esc_html__( 'Volume Up', 'heartify' ),
        'fa-qrcode' => esc_html__( 'Qrcode', 'heartify' ),
        'fa-barcode' => esc_html__( 'Barcode', 'heartify' ),
        'fa-tag' => esc_html__( 'Tag', 'heartify' ),
        'fa-tags' => esc_html__( 'Tags', 'heartify' ),
        'fa-book' => esc_html__( 'Book', 'heartify' ),
        'fa-bookmark' => esc_html__( 'Bookmark', 'heartify' ),
        'fa-print' => esc_html__( 'Print', 'heartify' ),
        'fa-camera' => esc_html__( 'Camera', 'heartify' ),
        'fa-font' => esc_html__( 'Font', 'heartify' ),
        'fa-bold' => esc_html__( 'Bold', 'heartify' ),
        'fa-italic' => esc_html__( 'Italic', 'heartify' ),
        'fa-text-height' => esc_html__( 'Text Height', 'heartify' ),
        'fa-text-width' => esc_html__( 'Text Width', 'heartify' ),
        'fa-align-left' => esc_html__( 'Align Left', 'heartify' ),
        'fa-align-center' => esc_html__( 'Align Center', 'heartify' ),
        'fa-align-right' => esc_html__( 'Align Right', 'heartify' ),
        'fa-align-justify' => esc_html__( 'Align Justify', 'heartify' ),
        'fa-list' => esc_html__( 'List', 'heartify' ),
        'fa-dedent' => esc_html__( 'Dedent', 'heartify' ),
        'fa-outdent' => esc_html__( 'Outdent', 'heartify' ),
        'fa-indent' => esc_html__( 'Indent', 'heartify' ),
        'fa-video-camera' => esc_html__( 'Video Camera', 'heartify' ),
        'fa-picture-o' => esc_html__( 'Picture Outline', 'heartify' ),
        'fa-pencil' => esc_html__( 'Pencil', 'heartify' ),
        'fa-map-marker' => esc_html__( 'Map Marker', 'heartify' ),
        'fa-adjust' => esc_html__( 'Adjust', 'heartify' ),
        'fa-tint' => esc_html__( 'Tint', 'heartify' ),
        'fa-edit' => esc_html__( 'Edit', 'heartify' ),
        'fa-pencil-square-o' => esc_html__( 'Pencil Square Outline', 'heartify' ),
        'fa-share-square-o' => esc_html__( 'Share Square Outline', 'heartify' ),
        'fa-check-square-o' => esc_html__( 'Check Square Outline', 'heartify' ),
        'fa-arrows' => esc_html__( 'Arrows', 'heartify' ),
        'fa-step-backward' => esc_html__( 'Step Backward', 'heartify' ),
        'fa-fast-backward' => esc_html__( 'Fast Backward', 'heartify' ),
        'fa-backward' => esc_html__( 'Backward', 'heartify' ),
        'fa-play' => esc_html__( 'Play', 'heartify' ),
        'fa-pause' => esc_html__( 'Pause', 'heartify' ),
        'fa-stop' => esc_html__( 'Stop', 'heartify' ),
        'fa-forward' => esc_html__( 'Forward', 'heartify' ),
        'fa-fast-forward' => esc_html__( 'Fast Forward', 'heartify' ),
        'fa-step-forward' => esc_html__( 'Step Forward', 'heartify' ),
        'fa-eject' => esc_html__( 'Eject', 'heartify' ),
        'fa-chevron-left' => esc_html__( 'Chevron Left', 'heartify' ),
        'fa-chevron-right' => esc_html__( 'Chevron Right', 'heartify' ),
        'fa-plus-circle' => esc_html__( 'Plus Circle', 'heartify' ),
        'fa-minus-circle' => esc_html__( 'Minus Circle', 'heartify' ),
        'fa-times-circle' => esc_html__( 'Times Circle', 'heartify' ),
        'fa-check-circle' => esc_html__( 'Check Circle', 'heartify' ),
        'fa-question-circle' => esc_html__( 'Question Circle', 'heartify' ),
        'fa-info-circle' => esc_html__( 'Info Circle', 'heartify' ),
        'fa-crosshairs' => esc_html__( 'Crosshairs', 'heartify' ),
        'fa-times-circle-o' => esc_html__( 'Times Circle Outline', 'heartify' ),
        'fa-check-circle-o' => esc_html__( 'Check Circle Outline', 'heartify' ),
        'fa-ban' => esc_html__( 'Ban', 'heartify' ),
        'fa-arrow-left' => esc_html__( 'Arrow Left', 'heartify' ),
        'fa-arrow-right' => esc_html__( 'Arrow Right', 'heartify' ),
        'fa-arrow-up' => esc_html__( 'Arrow Up', 'heartify' ),
        'fa-arrow-down' => esc_html__( 'Arrow Down', 'heartify' ),
        'fa-mail-forward' => esc_html__( 'Mail Forward', 'heartify' ),
        'fa-share' => esc_html__( 'Share', 'heartify' ),
        'fa-expand' => esc_html__( 'Expand', 'heartify' ),
        'fa-compress' => esc_html__( 'Compress', 'heartify' ),
        'fa-plus' => esc_html__( 'Plus', 'heartify' ),
        'fa-minus' => esc_html__( 'Minus', 'heartify' ),
        'fa-asterisk' => esc_html__( 'Asterisk', 'heartify' ),
        'fa-exclamation-circle' => esc_html__( 'Exclamation Circle', 'heartify' ),
        'fa-gift' => esc_html__( 'Gift', 'heartify' ),
        'fa-leaf' => esc_html__( 'Leaf', 'heartify' ),
        'fa-fire' => esc_html__( 'Fire', 'heartify' ),
        'fa-eye' => esc_html__( 'Eye', 'heartify' ),
        'fa-eye-slash' => esc_html__( 'Eye Slash', 'heartify' ),
        'fa-warning' => esc_html__( 'Warning', 'heartify' ),
        'fa-exclamation-triangle' => esc_html__( 'Exclamation Triangle', 'heartify' ),
        'fa-plane' => esc_html__( 'Plane', 'heartify' ),
        'fa-calendar' => esc_html__( 'Calendar', 'heartify' ),
        'fa-random' => esc_html__( 'Random', 'heartify' ),
        'fa-comment' => esc_html__( 'Comment', 'heartify' ),
        'fa-magnet' => esc_html__( 'Magnet', 'heartify' ),
        'fa-chevron-up' => esc_html__( 'Chevron Up', 'heartify' ),
        'fa-chevron-down' => esc_html__( 'Chevron Down', 'heartify' ),
        'fa-retweet' => esc_html__( 'Retweet', 'heartify' ),
        'fa-shopping-cart' => esc_html__( 'Shopping Cart', 'heartify' ),
        'fa-folder' => esc_html__( 'Folder', 'heartify' ),
        'fa-folder-open' => esc_html__( 'Folder Open', 'heartify' ),
        'fa-arrows-v' => esc_html__( 'Arrows V', 'heartify' ),
        'fa-arrows-h' => esc_html__( 'Arrows H', 'heartify' ),
        'fa-bar-chart-o' => esc_html__( 'Bar Chart Outline', 'heartify' ),
        'fa-twitter-square' => esc_html__( 'Twitter Square', 'heartify' ),
        'fa-facebook-square' => esc_html__( 'Facebook Square', 'heartify' ),
        'fa-camera-retro' => esc_html__( 'Camera Retro', 'heartify' ),
        'fa-key' => esc_html__( 'Key', 'heartify' ),
        'fa-gears' => esc_html__( 'Gears', 'heartify' ),
        'fa-cogs' => esc_html__( 'Cogs', 'heartify' ),
        'fa-comments' => esc_html__( 'Comments', 'heartify' ),
        'fa-thumbs-o-up' => esc_html__( 'Thumbs Outline Up', 'heartify' ),
        'fa-thumbs-o-down' => esc_html__( 'Thumbs Outline Down', 'heartify' ),
        'fa-star-half' => esc_html__( 'Star Half', 'heartify' ),
        'fa-heart-o' => esc_html__( 'Heart Outline', 'heartify' ),
        'fa-sign-out' => esc_html__( 'Sign Out', 'heartify' ),
        'fa-linkedin-square' => esc_html__( 'Linkedin Square', 'heartify' ),
        'fa-thumb-tack' => esc_html__( 'Thumb Tack', 'heartify' ),
        'fa-external-link' => esc_html__( 'External Link', 'heartify' ),
        'fa-sign-in' => esc_html__( 'Sign In', 'heartify' ),
        'fa-trophy' => esc_html__( 'Trophy', 'heartify' ),
        'fa-github-square' => esc_html__( 'Github Square', 'heartify' ),
        'fa-upload' => esc_html__( 'Upload', 'heartify' ),
        'fa-lemon-o' => esc_html__( 'Lemon Outline', 'heartify' ),
        'fa-phone' => esc_html__( 'Phone', 'heartify' ),
        'fa-square-o' => esc_html__( 'Square Outline', 'heartify' ),
        'fa-bookmark-o' => esc_html__( 'Bookmark Outline', 'heartify' ),
        'fa-phone-square' => esc_html__( 'Phone Square', 'heartify' ),
        'fa-twitter' => esc_html__( 'Twitter', 'heartify' ),
        'fa-facebook' => esc_html__( 'Facebook', 'heartify' ),
        'fa-github' => esc_html__( 'Github', 'heartify' ),
        'fa-unlock' => esc_html__( 'Unlock', 'heartify' ),
        'fa-credit-card' => esc_html__( 'Credit Card', 'heartify' ),
        'fa-rss' => esc_html__( 'Rss', 'heartify' ),
        'fa-hdd-o' => esc_html__( 'Hdd Outline', 'heartify' ),
        'fa-bullhorn' => esc_html__( 'Bullhorn', 'heartify' ),
        'fa-bell' => esc_html__( 'Bell', 'heartify' ),
        'fa-certificate' => esc_html__( 'Certificate', 'heartify' ),
        'fa-hand-o-right' => esc_html__( 'Hand Outline Right', 'heartify' ),
        'fa-hand-o-left' => esc_html__( 'Hand Outline Left', 'heartify' ),
        'fa-hand-o-up' => esc_html__( 'Hand Outline Up', 'heartify' ),
        'fa-hand-o-down' => esc_html__( 'Hand Outline Down', 'heartify' ),
        'fa-arrow-circle-left' => esc_html__( 'Arrow Circle Left', 'heartify' ),
        'fa-arrow-circle-right' => esc_html__( 'Arrow Circle Right', 'heartify' ),
        'fa-arrow-circle-up' => esc_html__( 'Arrow Circle Up', 'heartify' ),
        'fa-arrow-circle-down' => esc_html__( 'Arrow Circle Down', 'heartify' ),
        'fa-globe' => esc_html__( 'Globe', 'heartify' ),
        'fa-wrench' => esc_html__( 'Wrench', 'heartify' ),
        'fa-tasks' => esc_html__( 'Tasks', 'heartify' ),
        'fa-filter' => esc_html__( 'Filter', 'heartify' ),
        'fa-briefcase' => esc_html__( 'Briefcase', 'heartify' ),
        'fa-arrows-alt' => esc_html__( 'Arrows Alt', 'heartify' ),
        'fa-group' => esc_html__( 'Group', 'heartify' ),
        'fa-users' => esc_html__( 'Users', 'heartify' ),
        'fa-chain' => esc_html__( 'Chain', 'heartify' ),
        'fa-link' => esc_html__( 'Link', 'heartify' ),
        'fa-cloud' => esc_html__( 'Cloud', 'heartify' ),
        'fa-flask' => esc_html__( 'Flask', 'heartify' ),
        'fa-cut' => esc_html__( 'Cut', 'heartify' ),
        'fa-scissors' => esc_html__( 'Scissors', 'heartify' ),
        'fa-copy' => esc_html__( 'Copy', 'heartify' ),
        'fa-files-o' => esc_html__( 'Files Outline', 'heartify' ),
        'fa-paperclip' => esc_html__( 'Paperclip', 'heartify' ),
        'fa-save' => esc_html__( 'Save', 'heartify' ),
        'fa-floppy-o' => esc_html__( 'Floppy Outline', 'heartify' ),
        'fa-square' => esc_html__( 'Square', 'heartify' ),
        'fa-bars' => esc_html__( 'Bars', 'heartify' ),
        'fa-list-ul' => esc_html__( 'List Ul', 'heartify' ),
        'fa-list-ol' => esc_html__( 'List Ol', 'heartify' ),
        'fa-strikethrough' => esc_html__( 'Strikethrough', 'heartify' ),
        'fa-underline' => esc_html__( 'Underline', 'heartify' ),
        'fa-table' => esc_html__( 'Table', 'heartify' ),
        'fa-magic' => esc_html__( 'Magic', 'heartify' ),
        'fa-truck' => esc_html__( 'Truck', 'heartify' ),
        'fa-pinterest' => esc_html__( 'Pinterest', 'heartify' ),
        'fa-pinterest-square' => esc_html__( 'Pinterest Square', 'heartify' ),
        'fa-google-plus-square' => esc_html__( 'Google Plus Square', 'heartify' ),
        'fa-google-plus' => esc_html__( 'Google Plus', 'heartify' ),
        'fa-money' => esc_html__( 'Money', 'heartify' ),
        'fa-caret-down' => esc_html__( 'Caret Down', 'heartify' ),
        'fa-caret-up' => esc_html__( 'Caret Up', 'heartify' ),
        'fa-caret-left' => esc_html__( 'Caret Left', 'heartify' ),
        'fa-caret-right' => esc_html__( 'Caret Right', 'heartify' ),
        'fa-columns' => esc_html__( 'Columns', 'heartify' ),
        'fa-unsorted' => esc_html__( 'Unsorted', 'heartify' ),
        'fa-sort' => esc_html__( 'Sort', 'heartify' ),
        'fa-sort-down' => esc_html__( 'Sort Down', 'heartify' ),
        'fa-sort-asc' => esc_html__( 'Sort Asc', 'heartify' ),
        'fa-sort-up' => esc_html__( 'Sort Up', 'heartify' ),
        'fa-sort-desc' => esc_html__( 'Sort Desc', 'heartify' ),
        'fa-envelope' => esc_html__( 'Envelope', 'heartify' ),
        'fa-linkedin' => esc_html__( 'Linkedin', 'heartify' ),
        'fa-rotate-left' => esc_html__( 'Rotate Left', 'heartify' ),
        'fa-undo' => esc_html__( 'Undo', 'heartify' ),
        'fa-legal' => esc_html__( 'Legal', 'heartify' ),
        'fa-gavel' => esc_html__( 'Gavel', 'heartify' ),
        'fa-dashboard' => esc_html__( 'Dashboard', 'heartify' ),
        'fa-tachometer' => esc_html__( 'Tachometer', 'heartify' ),
        'fa-comment-o' => esc_html__( 'Comment Outline', 'heartify' ),
        'fa-comments-o' => esc_html__( 'Comments Outline', 'heartify' ),
        'fa-flash' => esc_html__( 'Flash', 'heartify' ),
        'fa-bolt' => esc_html__( 'Bolt', 'heartify' ),
        'fa-sitemap' => esc_html__( 'Sitemap', 'heartify' ),
        'fa-umbrella' => esc_html__( 'Umbrella', 'heartify' ),
        'fa-paste' => esc_html__( 'Paste', 'heartify' ),
        'fa-clipboard' => esc_html__( 'Clipboard', 'heartify' ),
        'fa-lightbulb-o' => esc_html__( 'Lightbulb Outline', 'heartify' ),
        'fa-exchange' => esc_html__( 'Exchange', 'heartify' ),
        'fa-cloud-download' => esc_html__( 'Cloud Download', 'heartify' ),
        'fa-cloud-upload' => esc_html__( 'Cloud Upload', 'heartify' ),
        'fa-user-md' => esc_html__( 'User Md', 'heartify' ),
        'fa-stethoscope' => esc_html__( 'Stethoscope', 'heartify' ),
        'fa-suitcase' => esc_html__( 'Suitcase', 'heartify' ),
        'fa-bell-o' => esc_html__( 'Bell Outline', 'heartify' ),
        'fa-coffee' => esc_html__( 'Coffee', 'heartify' ),
        'fa-cutlery' => esc_html__( 'Cutlery', 'heartify' ),
        'fa-file-text-o' => esc_html__( 'File Text Outline', 'heartify' ),
        'fa-building-o' => esc_html__( 'Building Outline', 'heartify' ),
        'fa-hospital-o' => esc_html__( 'Hospital Outline', 'heartify' ),
        'fa-ambulance' => esc_html__( 'Ambulance', 'heartify' ),
        'fa-medkit' => esc_html__( 'Medkit', 'heartify' ),
        'fa-fighter-jet' => esc_html__( 'Fighter Jet', 'heartify' ),
        'fa-beer' => esc_html__( 'Beer', 'heartify' ),
        'fa-h-square' => esc_html__( 'H Square', 'heartify' ),
        'fa-plus-square' => esc_html__( 'Plus Square', 'heartify' ),
        'fa-angle-double-left' => esc_html__( 'Angle Double Left', 'heartify' ),
        'fa-angle-double-right' => esc_html__( 'Angle Double Right', 'heartify' ),
        'fa-angle-double-up' => esc_html__( 'Angle Double Up', 'heartify' ),
        'fa-angle-double-down' => esc_html__( 'Angle Double Down', 'heartify' ),
        'fa-angle-left' => esc_html__( 'Angle Left', 'heartify' ),
        'fa-angle-right' => esc_html__( 'Angle Right', 'heartify' ),
        'fa-angle-up' => esc_html__( 'Angle Up', 'heartify' ),
        'fa-angle-down' => esc_html__( 'Angle Down', 'heartify' ),
        'fa-desktop' => esc_html__( 'Desktop', 'heartify' ),
        'fa-laptop' => esc_html__( 'Laptop', 'heartify' ),
        'fa-tablet' => esc_html__( 'Tablet', 'heartify' ),
        'fa-mobile-phone' => esc_html__( 'Mobile Phone', 'heartify' ),
        'fa-mobile' => esc_html__( 'Mobile', 'heartify' ),
        'fa-circle-o' => esc_html__( 'Circle Outline', 'heartify' ),
        'fa-quote-left' => esc_html__( 'Quote Left', 'heartify' ),
        'fa-quote-right' => esc_html__( 'Quote Right', 'heartify' ),
        'fa-spinner' => esc_html__( 'Spinner', 'heartify' ),
        'fa-circle' => esc_html__( 'Circle', 'heartify' ),
        'fa-mail-reply' => esc_html__( 'Mail Reply', 'heartify' ),
        'fa-reply' => esc_html__( 'Reply', 'heartify' ),
        'fa-github-alt' => esc_html__( 'Github Alt', 'heartify' ),
        'fa-folder-o' => esc_html__( 'Folder Outline', 'heartify' ),
        'fa-folder-open-o' => esc_html__( 'Folder Open Outline', 'heartify' ),
        'fa-smile-o' => esc_html__( 'Smile Outline', 'heartify' ),
        'fa-frown-o' => esc_html__( 'Frown Outline', 'heartify' ),
        'fa-meh-o' => esc_html__( 'Meh Outline', 'heartify' ),
        'fa-gamepad' => esc_html__( 'Gamepad', 'heartify' ),
        'fa-keyboard-o' => esc_html__( 'Keyboard Outline', 'heartify' ),
        'fa-flag-o' => esc_html__( 'Flag Outline', 'heartify' ),
        'fa-flag-checkered' => esc_html__( 'Flag Checkered', 'heartify' ),
        'fa-terminal' => esc_html__( 'Terminal', 'heartify' ),
        'fa-code' => esc_html__( 'Code', 'heartify' ),
        'fa-reply-all' => esc_html__( 'Reply All', 'heartify' ),
        'fa-mail-reply-all' => esc_html__( 'Mail Reply All', 'heartify' ),
        'fa-star-half-empty' => esc_html__( 'Star Half Empty', 'heartify' ),
        'fa-star-half-full' => esc_html__( 'Star Half Full', 'heartify' ),
        'fa-star-half-o' => esc_html__( 'Star Half Outline', 'heartify' ),
        'fa-location-arrow' => esc_html__( 'Location Arrow', 'heartify' ),
        'fa-crop' => esc_html__( 'Crop', 'heartify' ),
        'fa-code-fork' => esc_html__( 'Code Fork', 'heartify' ),
        'fa-unlink' => esc_html__( 'Unlink', 'heartify' ),
        'fa-chain-broken' => esc_html__( 'Chain Broken', 'heartify' ),
        'fa-question' => esc_html__( 'Question', 'heartify' ),
        'fa-info' => esc_html__( 'Info', 'heartify' ),
        'fa-exclamation' => esc_html__( 'Exclamation', 'heartify' ),
        'fa-superscript' => esc_html__( 'Superscript', 'heartify' ),
        'fa-subscript' => esc_html__( 'Subscript', 'heartify' ),
        'fa-eraser' => esc_html__( 'Eraser', 'heartify' ),
        'fa-puzzle-piece' => esc_html__( 'Puzzle Piece', 'heartify' ),
        'fa-microphone' => esc_html__( 'Microphone', 'heartify' ),
        'fa-microphone-slash' => esc_html__( 'Microphone Slash', 'heartify' ),
        'fa-shield' => esc_html__( 'Shield', 'heartify' ),
        'fa-calendar-o' => esc_html__( 'Calendar Outline', 'heartify' ),
        'fa-fire-extinguisher' => esc_html__( 'Fire Extinguisher', 'heartify' ),
        'fa-rocket' => esc_html__( 'Rocket', 'heartify' ),
        'fa-maxcdn' => esc_html__( 'Maxcdn', 'heartify' ),
        'fa-chevron-circle-left' => esc_html__( 'Chevron Circle Left', 'heartify' ),
        'fa-chevron-circle-right' => esc_html__( 'Chevron Circle Right', 'heartify' ),
        'fa-chevron-circle-up' => esc_html__( 'Chevron Circle Up', 'heartify' ),
        'fa-chevron-circle-down' => esc_html__( 'Chevron Circle Down', 'heartify' ),
        'fa-html5' => esc_html__( 'Html5', 'heartify' ),
        'fa-css3' => esc_html__( 'Css3', 'heartify' ),
        'fa-anchor' => esc_html__( 'Anchor', 'heartify' ),
        'fa-unlock-alt' => esc_html__( 'Unlock Alt', 'heartify' ),
        'fa-bullseye' => esc_html__( 'Bullseye', 'heartify' ),
        'fa-ellipsis-h' => esc_html__( 'Ellipsis H', 'heartify' ),
        'fa-ellipsis-v' => esc_html__( 'Ellipsis V', 'heartify' ),
        'fa-rss-square' => esc_html__( 'Rss Square', 'heartify' ),
        'fa-play-circle' => esc_html__( 'Play Circle', 'heartify' ),
        'fa-ticket' => esc_html__( 'Ticket', 'heartify' ),
        'fa-minus-square' => esc_html__( 'Minus Square', 'heartify' ),
        'fa-minus-square-o' => esc_html__( 'Minus Square Outline', 'heartify' ),
        'fa-level-up' => esc_html__( 'Level Up', 'heartify' ),
        'fa-level-down' => esc_html__( 'Level Down', 'heartify' ),
        'fa-check-square' => esc_html__( 'Check Square', 'heartify' ),
        'fa-pencil-square' => esc_html__( 'Pencil Square', 'heartify' ),
        'fa-external-link-square' => esc_html__( 'External Link Square', 'heartify' ),
        'fa-share-square' => esc_html__( 'Share Square', 'heartify' ),
        'fa-compass' => esc_html__( 'Compass', 'heartify' ),
        'fa-toggle-down' => esc_html__( 'Toggle Down', 'heartify' ),
        'fa-caret-square-o-down' => esc_html__( 'Caret Square Outline Down', 'heartify' ),
        'fa-toggle-up' => esc_html__( 'Toggle Up', 'heartify' ),
        'fa-caret-square-o-up' => esc_html__( 'Caret Square Outline Up', 'heartify' ),
        'fa-toggle-right' => esc_html__( 'Toggle Right', 'heartify' ),
        'fa-caret-square-o-right' => esc_html__( 'Caret Square Outline Right', 'heartify' ),
        'fa-euro' => esc_html__( 'Euro', 'heartify' ),
        'fa-eur' => esc_html__( 'Eur', 'heartify' ),
        'fa-gbp' => esc_html__( 'Gbp', 'heartify' ),
        'fa-dollar' => esc_html__( 'Dollar', 'heartify' ),
        'fa-usd' => esc_html__( 'Usd', 'heartify' ),
        'fa-rupee' => esc_html__( 'Rupee', 'heartify' ),
        'fa-inr' => esc_html__( 'Inr', 'heartify' ),
        'fa-cny' => esc_html__( 'Cny', 'heartify' ),
        'fa-rmb' => esc_html__( 'Rmb', 'heartify' ),
        'fa-yen' => esc_html__( 'Yen', 'heartify' ),
        'fa-jpy' => esc_html__( 'Jpy', 'heartify' ),
        'fa-ruble' => esc_html__( 'Ruble', 'heartify' ),
        'fa-rouble' => esc_html__( 'Rouble', 'heartify' ),
        'fa-rub' => esc_html__( 'Rub', 'heartify' ),
        'fa-won' => esc_html__( 'Won', 'heartify' ),
        'fa-krw' => esc_html__( 'Krw', 'heartify' ),
        'fa-bitcoin' => esc_html__( 'Bitcoin', 'heartify' ),
        'fa-btc' => esc_html__( 'Btc', 'heartify' ),
        'fa-file' => esc_html__( 'File', 'heartify' ),
        'fa-file-text' => esc_html__( 'File Text', 'heartify' ),
        'fa-sort-alpha-asc' => esc_html__( 'Sort Alpha Asc', 'heartify' ),
        'fa-sort-alpha-desc' => esc_html__( 'Sort Alpha Desc', 'heartify' ),
        'fa-sort-amount-asc' => esc_html__( 'Sort Amount Asc', 'heartify' ),
        'fa-sort-amount-desc' => esc_html__( 'Sort Amount Desc', 'heartify' ),
        'fa-sort-numeric-asc' => esc_html__( 'Sort Numeric Asc', 'heartify' ),
        'fa-sort-numeric-desc' => esc_html__( 'Sort Numeric Desc', 'heartify' ),
        'fa-thumbs-up' => esc_html__( 'Thumbs Up', 'heartify' ),
        'fa-thumbs-down' => esc_html__( 'Thumbs Down', 'heartify' ),
        'fa-youtube-square' => esc_html__( 'Youtube Square', 'heartify' ),
        'fa-youtube' => esc_html__( 'Youtube', 'heartify' ),
        'fa-xing' => esc_html__( 'Xing', 'heartify' ),
        'fa-xing-square' => esc_html__( 'Xing Square', 'heartify' ),
        'fa-youtube-play' => esc_html__( 'Youtube Play', 'heartify' ),
        'fa-dropbox' => esc_html__( 'Dropbox', 'heartify' ),
        'fa-stack-overflow' => esc_html__( 'Stack Overflow', 'heartify' ),
        'fa-instagram' => esc_html__( 'Instagram', 'heartify' ),
        'fa-flickr' => esc_html__( 'Flickr', 'heartify' ),
        'fa-adn' => esc_html__( 'Adn', 'heartify' ),
        'fa-bitbucket' => esc_html__( 'Bitbucket', 'heartify' ),
        'fa-bitbucket-square' => esc_html__( 'Bitbucket Square', 'heartify' ),
        'fa-tumblr' => esc_html__( 'Tumblr', 'heartify' ),
        'fa-tumblr-square' => esc_html__( 'Tumblr Square', 'heartify' ),
        'fa-long-arrow-down' => esc_html__( 'Long Arrow Down', 'heartify' ),
        'fa-long-arrow-up' => esc_html__( 'Long Arrow Up', 'heartify' ),
        'fa-long-arrow-left' => esc_html__( 'Long Arrow Left', 'heartify' ),
        'fa-long-arrow-right' => esc_html__( 'Long Arrow Right', 'heartify' ),
        'fa-apple' => esc_html__( 'Apple', 'heartify' ),
        'fa-windows' => esc_html__( 'Windows', 'heartify' ),
        'fa-android' => esc_html__( 'Android', 'heartify' ),
        'fa-linux' => esc_html__( 'Linux', 'heartify' ),
        'fa-dribbble' => esc_html__( 'Dribbble', 'heartify' ),
        'fa-skype' => esc_html__( 'Skype', 'heartify' ),
        'fa-foursquare' => esc_html__( 'Foursquare', 'heartify' ),
        'fa-trello' => esc_html__( 'Trello', 'heartify' ),
        'fa-female' => esc_html__( 'Female', 'heartify' ),
        'fa-male' => esc_html__( 'Male', 'heartify' ),
        'fa-gittip' => esc_html__( 'Gittip', 'heartify' ),
        'fa-sun-o' => esc_html__( 'Sun Outline', 'heartify' ),
        'fa-moon-o' => esc_html__( 'Moon Outline', 'heartify' ),
        'fa-archive' => esc_html__( 'Archive', 'heartify' ),
        'fa-bug' => esc_html__( 'Bug', 'heartify' ),
        'fa-vk' => esc_html__( 'Vk', 'heartify' ),
        'fa-weibo' => esc_html__( 'Weibo', 'heartify' ),
        'fa-renren' => esc_html__( 'Renren', 'heartify' ),
        'fa-pagelines' => esc_html__( 'Pagelines', 'heartify' ),
        'fa-stack-exchange' => esc_html__( 'Stack Exchange', 'heartify' ),
        'fa-arrow-circle-o-right' => esc_html__( 'Arrow Circle Outline Right', 'heartify' ),
        'fa-arrow-circle-o-left' => esc_html__( 'Arrow Circle Outline Left', 'heartify' ),
        'fa-toggle-left' => esc_html__( 'Toggle Left', 'heartify' ),
        'fa-caret-square-o-left' => esc_html__( 'Caret Square Outline Left', 'heartify' ),
        'fa-dot-circle-o' => esc_html__( 'Dot Circle Outline', 'heartify' ),
        'fa-wheelchair' => esc_html__( 'Wheelchair', 'heartify' ),
        'fa-vimeo-square' => esc_html__( 'Vimeo Square', 'heartify' ),
        'fa-turkish-lira' => esc_html__( 'Turkish Lira', 'heartify' ),
        'fa-try' => esc_html__( 'Try', 'heartify' ),
        'fa-plus-square-o' => esc_html__( 'Plus Square Outline', 'heartify' )
     );
}

function spyropress_get_options_social() {
    return array(
        'dribbble' => esc_html__( 'Dribbble', 'heartify' ),
        'dropbox' => esc_html__( 'Dropbox', 'heartify' ),
        'envelope' => esc_html__( 'Envelope', 'heartify' ),
        'facebook' => esc_html__( 'FaceBook', 'heartify' ),
        'foursquare' => esc_html__( 'Foursquare', 'heartify' ),
        'github' => esc_html__( 'Github ', 'heartify' ),
        'google-plus' => esc_html__( 'Google+', 'heartify' ),
        'instagram' => esc_html__( 'Instagram', 'heartify' ),
        'linkedin' => esc_html__( 'Linkedin', 'heartify' ),
        'maxcdn' => esc_html__( 'Maxcdn', 'heartify' ),
        'pinterest' => esc_html__( 'Pinterest', 'heartify' ),
        'rss' => esc_html__( 'Rss', 'heartify' ),
        'skype' => esc_html__( 'Skype', 'heartify' ),
        'tumblr' => esc_html__( 'Tumblr', 'heartify' ),
        'twitter' => esc_html__( 'Twitter', 'heartify' ),
        'vk' => esc_html__( 'Vk', 'heartify' ),
        'youtube' => esc_html__( 'Youtube', 'heartify' ), 
    );
}

function spyropress_get_social_icons( $id = '' , $class = 'footer-social' ){
    
    //get social icons.
    if(  $social_icons = get_setting_array( $id ) ){
        $icons = '';
        foreach ( $social_icons as $social_icon )
            $icons .= '<li><a href="'. esc_url( $social_icon['url'] ) .'"><i class="fa fa-'. esc_attr( $social_icon['network'] ) .'"></i></a></li>';
        
        echo '<ul class="'. esc_attr( $class ) .'">'. $icons .'</ul>';
    }
}

function spyropress_get_price_table() {

    $sliders = array();

    if ( !post_type_exists( 'pricingtable' ) )
        return $sliders;

    // get posts
    $args = array(
        'post_type' => 'pricingtable',
        'posts_per_page' => -1,
        'orderby' => 'title',
        'order' => 'asc'
    );
    $posts = get_posts( $args );
    if ( !empty( $posts ) ) {
        foreach ( $posts as $post ) {
            $sliders[$post->ID] = $post->post_title;
        }
    }

    return $sliders;
}
function spyropress_get_layer_slider(){
    if(  function_exists( 'lsSliders' ) ){
        $ls_sliders = lsSliders();
        $slider = array();
        foreach($ls_sliders as $sliders ){
            $slider[$sliders['slug']] = $sliders['name'];
        }
        
        //return slider ids.
        return  $slider;    
    }
}