<?php

/**
 * SpyroPress is a theme framework for professional WordPress theme designing developed by SpyroSol.
 *
 * DON'T HACK ME!! You should NOT modify the SpyroPress theme framework to avoid issues with updates in the future.
 * It's designed to offer cutting edge flexibility - with lots of ways to manipulate output!
 *
 * @package SpyroPress
 */

/**
 * Set Max Content Width
 */
if ( ! isset( $content_width ) )
    $content_width = 726;

if( !function_exists( 'spyropress_content_width' ) ) {
    function spyropress_content_width() {
        if( is_page_template( 'template-full-width.php' ) || is_attachment() ) {
            global $content_width;
            $content_width = 960;
        }
    }
}
add_action( 'template_redirect', 'spyropress_content_width' );

/**
 * Starting SpyroPress Engine
 */
load_template( get_template_directory() . '/framework/spyropress.php', true );
load_template( get_template_directory() . '/includes/init.php', true ); // Extending theme

/**
 * Add theme support for spyropress framework features
 */
add_action( 'after_setup_theme', 'spyropress_my_theme_setup', 4 );
function spyropress_my_theme_setup() {

    // Add wordpress features
    add_theme_support( 'automatic-feed-links' );

    // Add post thumbnails (http://codex.wordpress.org/Post_Thumbnails)
    add_theme_support( 'post-thumbnails' );
    
    // Tell the TinyMCE editor to use a custom stylesheet
    add_editor_style( assets_css() . 'editor-style.css' );
    
    // Root Relative Urls Support
    add_theme_support( 'relative-urls' );
    
    //Title of theme
    add_theme_support( "title-tag" ); 

    // SpyroPress Builder
    add_theme_support( 'spyropress-builder' );
	
	// Custom CSS Editor
    add_theme_support( 'spyropress-ace' );
    
    $spyropress_defaults = array(
    	'default-image'          => '',
    	'random-default'         => false,
    	'width'                  => 0,
    	'height'                 => 0,
    	'flex-height'            => false,
    	'flex-width'             => false,
    	'default-text-color'     => '',
    	'header-text'            => true,
    	'uploads'                => true,
    	'wp-head-callback'       => '',
    	'admin-head-callback'    => '',
    	'admin-preview-callback' => '',
    );
    add_theme_support( 'custom-header', $spyropress_defaults );
    
    $spyropress_defaults = array(
    	'default-color'          => '',
    	'default-image'          => '',
    	'default-repeat'         => '',
    	'default-position-x'     => '',
    	'default-attachment'     => '',
    	'wp-head-callback'       => '_custom_background_cb',
    	'admin-head-callback'    => '',
    	'admin-preview-callback' => ''
    );
    add_theme_support( 'custom-background', $spyropress_defaults );

    // Add post formats (http://codex.wordpress.org/Post_Formats)
    add_theme_support( 'post-formats', array(
        'gallery',
        'image',
        'quote',
        'video',
        'audio',
    ) );

    // Add Components
    add_theme_support( 'spyropress-components', array(
        'bucket',
        'staff',
        'page',
        'portfolio',
        'pricing-table',
        'bootstrap-nav',
        'pagination'
    ) );

    // Add Menus
    add_theme_support( 'spyropress-core-menus', array(
        'primary' => 'Main'
    ) );

    // Add Sidebars
    $spyropress_sidebars = array(
        'primary' => array(
            'name' => esc_html__( 'Primary', 'heartify' ),
            'description' => esc_html__( 'The main (primary) widget area, most often used as a sidebar.','heartify' ),
            'before_widget' => '<div id="%1$s" class="side-content %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h5>',
            'after_title' => '</h5>'
        ),
    );
    add_theme_support( 'spyropress-core-sidebars', $spyropress_sidebars );

    // Options
    $spyropress_options = array(
        'theme' => array(
            'page_title' => esc_html__( 'Theme Options', 'heartify' ),
            'menu_title' => esc_html__( 'Theme Options', 'heartify' ),
            'isactive' => true,
            'hidden' => false
        )
    );
    add_theme_support( 'spyropress-options', $spyropress_options );
}

/**
 * Hide editor for specific page templates.
 *
 */
add_action( 'admin_init', 'spyrpress_hide_editor' );

function spyrpress_hide_editor() {
	// Get the Post ID.
	$spyropress_post_id = ( isset( $_POST['post_ID'] ) )? $_POST['post_ID'] : '';
	if( !isset( $spyropress_post_id ) ) return;

	// Get the name of the Page Template file.
	$spyropress_template_file = get_post_meta($spyropress_post_id, '_wp_page_template', true);
    
    if( $spyropress_template_file == 'landing-page.php' ){ // edit the template name
    	remove_post_type_support('page', 'editor');
    }
}

/* load demo data setting */
    require_once( get_template_directory() . '/inc/demo-data.php' );