<?php

/**
 * Enqueue scripts and stylesheets
 *
 * @category Core
 * @package SpyroPress
 *
 */
 add_action( 'init', 'spyropress_register_cf7', 11 );
function spyropress_register_cf7() {
    
    if( defined( 'WPCF7_VERSION' ) )
        wp_register_script( 'contact-form-7', assets_js() . 'contactform-script.js', array( 'jquery', 'jquery-form' ), WPCF7_VERSION, true );
    
    if( defined( 'WC_VERSION' ) )
        wp_register_script( 'wc-country-select', assets_js() . 'country-select' . '.js', array( 'jquery' ), WC_VERSION, true );
}
add_action( 'wp_enqueue_scripts', 'spyropress_deregister_cf7' );
function spyropress_deregister_cf7() {
    wp_dequeue_style( 'contact-form-7' );

	if ( function_exists( 'wpcf7_is_rtl' ) && wpcf7_is_rtl() ) {
		wp_dequeue_style( 'contact-form-7-rtl' );
	}
}

/**
 *  Google Fonts Register StyleSheets
 */
function spyropress_fonts_url() {
    $fonts_url = '';
 
    /* Translators: If there are characters in your language that are not
    * supported by Raleway, translate this to 'off'. Do not translate
    * into your own language.
    */
    $raleway = _x( 'on', 'Raleway font: on or off', 'heartify' );
 
    /* Translators: If there are characters in your language that are not
    * supported by Open Sans, translate this to 'off'. Do not translate
    * into your own language.
    */
    $open_sans = _x( 'on', 'Open Sans font: on or off', 'heartify' );
 
    if ( 'off' !== $raleway || 'off' !== $open_sans ) {
        $font_families = array();
 
        if ( 'off' !== $raleway ) {
            $font_families[] = 'Raleway:100,200,300,400,500,600,700,800,900';
        }
 
        if ( 'off' !== $open_sans ) {
            $font_families[] = 'Open Sans:300,400,600,700';
        }
 
        $query_args = array(
            'family' => urlencode( implode( '|', $font_families ) ),
        );
 
        $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
    }
 
    return esc_url_raw( $fonts_url );
}
function spyropress_scripts_styles() {
    wp_enqueue_style( 'spyropress-fonts', spyropress_fonts_url(), array(), null );
}
add_action( 'wp_enqueue_scripts', 'spyropress_scripts_styles' );

/**
 * Register StyleSheets
 */
function spyropress_register_stylesheets() {
    
    // Default stylesheets
    wp_enqueue_style( 'bootstrap', assets() . 'vendor/bootstrap/css/bootstrap.min.css', false, '3.1.1' );
    wp_enqueue_style( 'style', assets_css() . 'style.css', false, false );
    
    // Responsiveness
    $spyropress_responsive_layout = get_setting( 'responsive-layout', false );
    if ( $spyropress_responsive_layout )
        wp_enqueue_style( 'responsive-styling', assets_css() . 'responsive-styling.css', false, false );

    //plug in stylesheets.
    wp_enqueue_style( 'owl-carousel', assets() . 'vendor/owl-carousel/owl-carousel/owl.carousel.css', false, '1.3.2' );
    wp_enqueue_style( 'owl-theme', assets() . 'vendor/owl-carousel/owl-carousel/owl.theme.css', false, '1.3.2' );
    wp_enqueue_style( 'font-awesome', assets_css() . 'fonts/font-awesome.min.css', false, '4.1.0' );

    // Dynamic StyleSheet
    if ( file_exists( dynamic_css_path() . 'dynamic.css' ) )
        wp_enqueue_style( 'dynamic', dynamic_css_url() . 'dynamic.css', false, '2.0.0' );

    // Builder StyleSheet
    if ( file_exists( dynamic_css_path() . 'builder.css' ) )
        wp_enqueue_style( 'builder', dynamic_css_url() . 'builder.css', false, '2.0.0' );

    // jquery
    wp_enqueue_script( 'jquery', assets_js() . 'jquery', '2.6.2', false );
}

/**
 * Enqueque Scripts
 */
function spyropress_register_scripts() {

    /**
     * Register Scripts
     */
    // threaded comments
    if ( is_single() && comments_open() && get_option( 'thread_comments' ) )
        wp_enqueue_script( 'comment-reply' );

    // Plugins
    wp_register_script( 'jquery-bootstrap', assets() . 'vendor/bootstrap/js/bootstrap.min.js', false, '3.1.1', true );
    wp_register_script( 'jquery-carousel', assets() . 'vendor/owl-carousel/owl-carousel/owl.carousel.js', false, '1.3.2', true );
    wp_register_script( 'jquery-isotope', assets() . 'vendor/isotope/isotope.pkgd.min.js', false, '2.0.0', true );
    wp_register_script( 'jquery-stellar', assets_js() . 'stellar.js', false, '2.0.2', true );
    wp_register_script( 'jquery-mediaelement', assets() . 'vendor/mediaelement/mediaelement.js', false, '2.0.2', true );
    wp_register_script( 'jquery-easing', assets_js() . 'jquery.easing.min.js', false, '2.0.2', true );
    wp_register_script( 'jquery-easypiechart', assets_js() . 'jquery.easypiechart.js', false, '2.0.2', true );
    wp_register_script( 'jquery-nav', assets_js() . 'jquery.nav.js', false, '2.0.2', true );
    wp_register_script( 'jquery-sticky', assets_js() . 'jquery.sticky.js', false, '2.0.2', true );
    wp_register_script( 'jquery-vide', assets() . 'vendor/vide/vide.js', false, false, true );
    
    
    $spyropress_deps = array(
        'jquery-bootstrap',
        'jquery-carousel',
        'jquery-isotope',
        'jquery-stellar',
        'jquery-mediaelement',
        'jquery-easing',
        'jquery-easypiechart',
        'jquery-nav',
        'jquery-sticky',
        'jquery-vide'
        
    );
    
    // custom scripts
    wp_register_script( 'custom-script', assets_js() . 'custom-scripts.js', $spyropress_deps, false, true );

    /**
     * Enqueue All
     */
    wp_enqueue_script( 'custom-script' );
    
    /**
     * Enqueue All
     */
    $spyropress_settings = array(
        'site_assets' => assets(),
        'ajax_url' => admin_url( 'admin-ajax.php' ),
        'twitter_feed' => admin_url( 'admin-ajax.php?action=spyropress_twitter_tweets' ),
    );
    wp_localize_script( 'jquery-bootstrap', 'theme_settings', $spyropress_settings );
}

function spyropress_conditional_scripts() {

    $spyropress_content = '<!--[if lt IE 9]><script src="'. assets_js() .'ie8-responsive-file-warning.js"></script><![endif]-->
	<!--[if lt IE 9]>
		<script src="'. assets_js() .'html5shiv.js"></script>
		<script src="'. assets_js() .'respond.min.js"></script>
	<![endif]-->';

    echo get_relative_url( $spyropress_content );
}